package rendering;

import java.awt.Graphics;
import java.awt.Graphics2D;

import javax.swing.JPanel;


public class GameBoard extends JPanel {
	
	public static final int boardDimension = 9;

	public Drawable drawables[];
	
	private Field selectedField = null;
	
	public GameBoard() {
		drawables = new Drawable[boardDimension * boardDimension];
		
		initBoard();
	}
	
	private void initBoard() {
		for(int i = 0; i < drawables.length; i++) {
			int x = (i % boardDimension) * Field.width;
			int y = (i / boardDimension) * Field.height;
			
			drawables[i] = new Field(x, y, i / boardDimension);
		}
		//((Field)drawables[5]).select();
	}
	
	public Field getFieldByCoord(int x, int y) {
		for (Drawable drawable : drawables) {
			Field field = (Field)drawable;
			if(field.isInside(x, y)) {
				return field;
			}
		}
		return null;
	}
	
	public void selectByCoord(int x, int y) {
		getFieldByCoord(x, y).select();
	}
	
	public void deselectByCoord(int x, int y) {
		getFieldByCoord(x, y).deselect();
	}

	private void doDrawing(Graphics2D g2d) {
		for (Drawable drawable : drawables) {
			drawable.draw(g2d);
		}
	}
	
	@Override
	public void paintComponent(Graphics g) {

		super.paintComponent(g);
		doDrawing((Graphics2D)g);
	}
	
	public boolean isSomethingSelected() {
		if(selectedField == null) {
			return false;
		} else {
			return true;
		}
	}
	
	public void switchSelectedByCoord(int x, int y) {
		Field clickedField = getFieldByCoord(x, y);
		if(isSomethingSelected()) {
			if(selectedField == clickedField) {
				selectedField.deselect();
				selectedField = null;
			} else {
				selectedField.deselect();
				clickedField.select();
				selectedField = clickedField;
			}
		} else {
			clickedField.select();
			selectedField = clickedField;
		}
	}
}
